@@ -1,30 +1,16 @@
 /*
     This file is part of the Okteta Gui library, made within the KDE community.
 
-    Copyright 2008-2010 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2008-2010 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef OKTETA_ABSTRACTBYTEARRAYVIEW_HPP
 #define OKTETA_ABSTRACTBYTEARRAYVIEW_HPP
 
 // lib
-#include <okteta/columnsview.hpp>
+#include "columnsview.hpp"
 // Okteta core
 #include <Okteta/AddressRange>
 // Qt
@@ -62,6 +48,7 @@ class OKTETAGUI_EXPORT AbstractByteArrayView : public ColumnsView
     friend class MouseNavigator;
     friend class MousePaster;
     friend class Dragger;
+    friend class TapNavigator;
 
     Q_OBJECT
     Q_PROPERTY(bool OverwriteMode READ isOverwriteMode WRITE setOverwriteMode NOTIFY overwriteModeChanged)
@@ -463,6 +450,7 @@ protected: // QWidget API
     void dragLeaveEvent(QDragLeaveEvent* dragLeaveEvent) override;
     void dropEvent(QDropEvent* dropEvent) override;
     void contextMenuEvent(QContextMenuEvent* contextMenuEvent) override;
+    void timerEvent(QTimerEvent* timerEvent) override;
 
 protected: // QAbstractScrollArea API
     void wheelEvent(QWheelEvent* e) override;
