@@ -17,6 +17,7 @@
 #include <KColorScheme>
 // Qt
 #include <QApplication>
+#include <QFontDatabase>
 
 namespace Kasten {
 
@@ -29,6 +30,7 @@ ByteTableModel::ByteTableModel(QObject* parent)
     , mCharCodec(Okteta::CharCodec::createCodec(Okteta::LocalEncoding))
     , mSubstituteChar(ByteTableDefaultSubstituteChar)
     , mUndefinedChar(ByteTableDefaultUndefinedChar)
+    , mFixedFont(QFontDatabase::systemFont(QFontDatabase::FixedFont))
 {
     constexpr Okteta::ValueCoding CodingIds[NofOfValueCodings] = {
         Okteta::DecimalCoding,
@@ -137,7 +139,9 @@ QVariant ByteTableModel::data(const QModelIndex& index, int role) const
             }
         }
     } else if (role == Qt::TextAlignmentRole) {
-        result = Qt::AlignRight;
+        result = static_cast<int>(Qt::AlignVCenter | Qt::AlignRight);
+    } else if (role == Qt::FontRole) {
+        result = mFixedFont;
     }
 
     return result;
