@@ -13,18 +13,23 @@
 #include "bytetabletool.hpp"
 #include "bytetablemodel.hpp"
 #include <bytetableviewsettings.h>
+// utils
+#include <labelledtoolbarwidget.hpp>
 // KF
-#include <QPushButton>
 #include <KLocalizedString>
 #include <KStandardGuiItem>
 // Qt
 #include <QApplication>
+#include <QToolBar>
 #include <QSpinBox>
-#include <QFontDatabase>
 #include <QLabel>
-#include <QLayout>
+#include <QVBoxLayout>
 #include <QHeaderView>
 #include <QTreeView>
+#include <QAction>
+#include <QIcon>
+// Std
+#include <limits>
 
 namespace Kasten {
 
@@ -40,6 +45,7 @@ ByteTableView::ByteTableView(ByteTableTool* tool, QWidget* parent)
 {
     auto* baseLayout = new QVBoxLayout(this);
     baseLayout->setContentsMargins(0, 0, 0, 0);
+    baseLayout->setSpacing(0);
 
     mByteTableView = new QTreeView(this);
     // TODO: find a signal/event emitted when fixedfont changes
@@ -49,7 +55,6 @@ ByteTableView::ByteTableView(ByteTableTool* tool, QWidget* parent)
 //              this, &ByteTableView::resizeColumnsWidth );
 //     connect( KGlobalSettings::self(), &KGlobalSettings::kdisplayStyleChanged,
 //              this, &ByteTableView::resizeColumnsWidth );
-    setFixedFontByGlobalSettings(); // do this before setting model
     mByteTableView->setObjectName(QStringLiteral("ByteTable"));
     mByteTableView->setRootIsDecorated(false);
     mByteTableView->setItemsExpandable(false);
@@ -57,7 +62,6 @@ ByteTableView::ByteTableView(ByteTableTool* tool, QWidget* parent)
     mByteTableView->setAllColumnsShowFocus(true);
     mByteTableView->setSortingEnabled(false);
     QHeaderView* header = mByteTableView->header();
-    header->setFont(font());
     header->setSectionResizeMode(QHeaderView::Interactive);
     header->setStretchLastSection(false);
     mByteTableView->setModel(mTool->byteTableModel());
@@ -66,15 +70,19 @@ ByteTableView::ByteTableView(ByteTableTool* tool, QWidget* parent)
 
     baseLayout->addWidget(mByteTableView, 10);
 
-    auto* insertLayout = new QHBoxLayout();
+    auto* insertToolBar = new QToolBar(this);
+    insertToolBar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
+
+    auto* stretcher = new QWidget(this);
+    stretcher->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+    insertToolBar->addWidget(stretcher);
 
     QLabel* label = new QLabel(i18nc("@label:spinbox number of bytes to insert", "Number (bytes):"), this);
-    insertLayout->addWidget(label);
 
     mInsertCountEdit = new QSpinBox(this);
-    mInsertCountEdit->setRange(1, INT_MAX);
-    label->setBuddy(mInsertCountEdit);
-    insertLayout->addWidget(mInsertCountEdit);
+    mInsertCountEdit->setRange(1, std::numeric_limits<int>::max());
+    auto* labelledInsertCountEdit = new LabelledToolBarWidget(label, mInsertCountEdit, this);
+    insertToolBar->addWidget(labelledInsertCountEdit);
     const QString insertCountToolTip =
         i18nc("@info:tooltip",
               "Number of repeats of the currently selected byte in the table to be inserted.");
@@ -83,29 +91,33 @@ ByteTableView::ByteTableView(ByteTableTool* tool, QWidget* parent)
     connect(mInsertCountEdit, QOverload<int>::of(&QSpinBox::valueChanged),
             this, &ByteTableView::onInsertCountEditChanged);
 
-    insertLayout->addStretch();
-
-    mInsertButton = new QPushButton(this);
-    KGuiItem::assign(mInsertButton, KStandardGuiItem::insert());
-    mInsertButton->setEnabled(mTool->hasWriteable());
-    connect(mTool, &ByteTableTool::hasWriteableChanged, mInsertButton, &QPushButton::setEnabled);
-    connect(mInsertButton, &QPushButton::clicked, this, &ByteTableView::onInsertClicked);
+    const KGuiItem insertGuiItem = KStandardGuiItem::insert();
+    QIcon insertIcon = insertGuiItem.icon();
+    if (insertIcon.isNull()) {
+        insertIcon = QIcon::fromTheme(QStringLiteral("list-add"));
+    }
+    mInsertAction =
+        insertToolBar->addAction(insertIcon, insertGuiItem.text(),
+                                 this, &ByteTableView::onInsertClicked);
     const QString insertButtonToolTip =
         i18nc("@info:tooltip",
               "Insert the currently selected byte in the table repeated the given number of times.");
-    mInsertButton->setToolTip(insertButtonToolTip);
-    addButton(mInsertButton, AbstractToolWidget::Default);
-    insertLayout->addWidget(mInsertButton);
+    mInsertAction->setToolTip(insertButtonToolTip);
+    mInsertAction->setEnabled(mTool->hasWriteable());
+    connect(mTool, &ByteTableTool::hasWriteableChanged, mInsertAction, &QAction::setEnabled);
 
-    baseLayout->addLayout(insertLayout);
+    baseLayout->addWidget(insertToolBar);
 
     // if nothing has changed reuse the old values. This means the bytetable is fully constructed
     // after ~3ms and not 800 as it was before. If the saved values can not be reused it takes ~100ms
     const QList<int> columnsWidth = ByteTableViewSettings::columnsWidth();
     const QString styleName = QApplication::style()->objectName();
-    const QString fixedFontData = QFontDatabase::systemFont(QFontDatabase::FixedFont).toString();
-    if (columnsWidth.size() < ByteTableModel::NoOfIds || styleName != ByteTableViewSettings::style()
-        || fixedFontData != ByteTableViewSettings::fixedFont()) {
+    const QString fontData = mByteTableView->font().toString();
+    const QString fixedFontData = mTool->byteTableModel()->fixedFont().toString();
+    if ((ByteTableModel::NoOfIds > columnsWidth.size()) ||
+        (styleName != ByteTableViewSettings::style()) ||
+        (fontData != ByteTableViewSettings::font()) ||
+        (fixedFontData != ByteTableViewSettings::fixedFont())) {
         resizeColumnsWidth();
     } else {
         for (int i = 0; i < ByteTableModel::NoOfIds; ++i) {
@@ -131,7 +143,8 @@ ByteTableView::~ByteTableView()
 
     ByteTableViewSettings::setColumnsWidth(columnsWidth);
     ByteTableViewSettings::setStyle(QApplication::style()->objectName());
-    ByteTableViewSettings::setFixedFont(QFontDatabase::systemFont(QFontDatabase::FixedFont).toString());
+    ByteTableViewSettings::setFont(mByteTableView->font().toString());
+    ByteTableViewSettings::setFixedFont(mTool->byteTableModel()->fixedFont().toString());
     ByteTableViewSettings::self()->save();
 }
 
@@ -152,11 +165,6 @@ void ByteTableView::resizeColumnsWidth()
     }
 }
 
-void ByteTableView::setFixedFontByGlobalSettings()
-{
-    mByteTableView->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
-}
-
 void ByteTableView::onInsertCountEditChanged()
 {
     KConfigGroup configGroup(KSharedConfig::openConfig(), ByteTableConfigGroupId);
