@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2022 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -9,7 +9,7 @@
 // QCA
 // need to have this first, as QCA needs QT_NO_CAST_FROM_ASCII disabled when included
 #include <config-qca2.hpp> // krazy:excludeall=includes
-#ifdef HAVE_QCA2
+#if HAVE_QCA2
 // disable QT_NO_CAST_FROM_ASCII
 #ifdef QT_NO_CAST_FROM_ASCII
 #undef QT_NO_CAST_FROM_ASCII
@@ -33,10 +33,15 @@
 #include <Okteta/AbstractByteArrayModel>
 #include <Okteta/ArrayChangeMetricsList>
 // KF
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KLocalizedString>
 // Qt
 #include <QApplication>
 
+static constexpr char ChecksumConfigGroupId[] = "ChecksumTool";
+static constexpr char AlgorithmConfigKey[] = "Algorithm";
+
 namespace Kasten {
 
 ChecksumTool::ChecksumTool()
@@ -46,18 +51,34 @@ ChecksumTool::ChecksumTool()
     setObjectName(QStringLiteral("Checksum"));
 
 // TODO: find a better place to do and store the initialization
-#ifdef HAVE_QCA2
+#if HAVE_QCA2
     mQcaInitializer = new QCA::Initializer(QCA::Practical, 64);
     qCDebug(LOG_OKTETA_KASTEN_CONTROLLER_CHECKSUM) << QCA::supportedFeatures();// Hash::supportedTypes();
 #endif
 
     mAlgorithmList = ByteArrayChecksumAlgorithmFactory::createAlgorithms();
+
+    const KConfigGroup configGroup(KSharedConfig::openConfig(), ChecksumConfigGroupId);
+    for (auto *algorithm : qAsConst(mAlgorithmList)) {
+        algorithm->loadConfig(configGroup);
+    }
+
+    mAlgorithmId = 0;
+    const QString algorithmId = configGroup.readEntry(AlgorithmConfigKey);
+    if (!algorithmId.isEmpty()) {
+        for (int i = 0; i < mAlgorithmList.size(); ++i) {
+            if (mAlgorithmList[i]->id() == algorithmId) {
+                mAlgorithmId = i;
+                break;
+            }
+        }
+    }
 }
 
 ChecksumTool::~ChecksumTool()
 {
     qDeleteAll(mAlgorithmList);
-#ifdef HAVE_QCA2
+#if HAVE_QCA2
     delete mQcaInitializer;
 #endif
 }
@@ -147,8 +168,20 @@ void ChecksumTool::calculateChecksum()
 
 void ChecksumTool::setAlgorithm(int algorithmId)
 {
+    if (mAlgorithmId == algorithmId) {
+        return;
+    }
+
     mAlgorithmId = algorithmId;
     checkUptoDate();
+
+    AbstractByteArrayChecksumAlgorithm* algorithm = mAlgorithmList.at(mAlgorithmId);
+    if (algorithm) {
+        KConfigGroup configGroup(KSharedConfig::openConfig(), ChecksumConfigGroupId);
+        configGroup.writeEntry(AlgorithmConfigKey, algorithm->id());
+    }
+
+    emit algorithmChanged(mAlgorithmId);
     emit uptodateChanged(mChecksumUptodate);
     emit isApplyableChanged(isApplyable());
 }
@@ -160,6 +193,12 @@ void ChecksumTool::resetSourceTool()
 {
     mSourceAlgorithmId = -1;
 
+    AbstractByteArrayChecksumAlgorithm* algorithm = mAlgorithmList.at(mAlgorithmId);
+    if (algorithm) {
+        KConfigGroup configGroup(KSharedConfig::openConfig(), ChecksumConfigGroupId);
+        algorithm->saveConfig(configGroup);
+    }
+
     checkUptoDate();
     emit uptodateChanged(mChecksumUptodate);
     emit isApplyableChanged(isApplyable());
