@@ -31,6 +31,9 @@ public:
     void setWidgetData(QWidget* w) const override;
 
     QScriptValue valueAsQScriptValue() const override;
+    QVariant valueToQVariant() const override;
+    QString valueToQString(AllPrimitiveTypes value) const override;
+    QVariant valueToQVariant(AllPrimitiveTypes value) const override;
     BitCount32 size() const override; // TODO declare final with c++11 so it can be inlined
     bool setData(const QVariant& value, Okteta::AbstractByteArrayModel* out,
                  Okteta::Address address, BitCount64 bitsRemaining, quint8 bitOffset) override;
@@ -129,4 +132,22 @@ QString BasicPrimitiveDataInformation<T, C>::valueStringImpl() const
     return C::staticValueString(mValue);
 }
 
+template <typename T, typename C>
+QVariant BasicPrimitiveDataInformation<T, C>::valueToQVariant() const
+{
+    return C::staticToQVariant(mValue);
+}
+
+template <typename T, typename C>
+QString BasicPrimitiveDataInformation<T, C>::valueToQString(AllPrimitiveTypes value) const
+{
+    return C::staticValueString(value.value<T>());
+}
+
+template <typename T, typename C>
+QVariant BasicPrimitiveDataInformation<T, C>::valueToQVariant(AllPrimitiveTypes value) const
+{
+    return C::staticToQVariant(value.value<T>());
+}
+
 #endif /* KASTEN_BASICPRIMITIVEDATAINFORMATION_HPP */
