@@ -32,8 +32,11 @@ public:
     bool isPrimitive() const override;
     virtual AllPrimitiveTypes value() const = 0;
     virtual void setValue(AllPrimitiveTypes newValue) = 0;
+    virtual QVariant valueToQVariant() const = 0;
     virtual QScriptValue valueAsQScriptValue() const = 0;
     virtual PrimitiveDataType type() const = 0;
+    virtual QString valueToQString(AllPrimitiveTypes value) const = 0;
+    virtual QVariant valueToQVariant(AllPrimitiveTypes value) const = 0;
 
     unsigned int childCount() const override;
     DataInformation* childAt(unsigned int) const override;
@@ -89,8 +92,14 @@ public:
 
     PrimitiveDataType type() const override;
 
+    QVariant valueToQVariant() const override;
+
     QScriptValue valueAsQScriptValue() const override;
 
+    QString valueToQString(AllPrimitiveTypes value) const override;
+
+    QVariant valueToQVariant(AllPrimitiveTypes value) const override;
+
     // we have to do slightly more than just forward with this method
     qint64 readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                     BitCount64 bitsRemaining, quint8* bitOffset) override;
