@@ -1,24 +1,10 @@
 /*
- *   This file is part of the Okteta Kasten Framework, made within the KDE community.
- *
- *   Copyright 2010, 2011 Alex Richardson <alex.richardson@gmx.de>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
- */
+    This file is part of the Okteta Kasten Framework, made within the KDE community.
+
+    SPDX-FileCopyrightText: 2010, 2011 Alex Richardson <alex.richardson@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "topleveldatainformation.hpp"
 #include "datainformation.hpp"
@@ -46,7 +32,7 @@ constexpr TextStreamFunction hex = ::hex;
 #endif
 }
 
-const quint64 TopLevelDataInformation::INVALID_OFFSET = std::numeric_limits<quint64>::max();
+const Okteta::Address TopLevelDataInformation::INVALID_OFFSET = std::numeric_limits<Okteta::Address>::max();
 
 TopLevelDataInformation::TopLevelDataInformation(DataInformation* data, ScriptLogger* logger,
                                                  QScriptEngine* engine, const QFileInfo& structureFile)
@@ -93,6 +79,11 @@ void TopLevelDataInformation::read(Okteta::AbstractByteArrayModel* input, Okteta
                                    const Okteta::ArrayChangeMetricsList& changesList, bool forceRead)
 {
     mChildDataChanged = false;
+
+    if (isLockedFor(input)) {
+        address = lockPositionFor(input);
+    }
+
     const bool updateNeccessary = forceRead || isReadingNecessary(input, address, changesList);
     if (!updateNeccessary) {
         return;
@@ -137,11 +128,8 @@ bool TopLevelDataInformation::isReadingNecessary(Okteta::AbstractByteArrayModel*
         return true; // whenever we have a new model we have to read
 
     }
-    if (isLockedFor(model)) {
-        address = lockPositionFor(model);
-    }
 
-    if (quint64(address) != mLastReadOffset) {
+    if (address != mLastReadOffset) {
         return true; // address as changed, we have to read again
 
     }
@@ -191,16 +179,22 @@ bool TopLevelDataInformation::isReadingNecessary(Okteta::AbstractByteArrayModel*
 
 void TopLevelDataInformation::lockPositionToOffset(Okteta::Address offset, const Okteta::AbstractByteArrayModel* model)
 {
-    if (quint64(offset) == INVALID_OFFSET) {
-        // we use quint64 max to indicate not locked -> error out
-        mLogger->error() << "Attempting to lock at uint64_max, this is forbidden.";
+    if (offset == INVALID_OFFSET) {
+        // we use Okteta::Address max to indicate not locked -> error out
+        mLogger->error() << "Attempting to lock at max adress value, this is forbidden.";
         return;
     }
-    mLockedPositions.insert(model, quint64(offset));
+    auto it = mLockedPositions.find(model);
+    if (it != mLockedPositions.end()) {
+        it.value() = offset;
+    } else {
+        mLockedPositions.insert(model, offset);
+        // remove when deleted
+        connect(model, &Okteta::AbstractByteArrayModel::destroyed,
+                this, &TopLevelDataInformation::removeByteArrayModelFromList);
+    }
     qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
         << mData->name() << ": Locking start offset in model" << model << "to position" << Okteta::hex << offset;
-    // remove when deleted
-    connect(model, &Okteta::AbstractByteArrayModel::destroyed, this, &TopLevelDataInformation::removeByteArrayModelFromList);
 }
 
 void TopLevelDataInformation::unlockPosition(const Okteta::AbstractByteArrayModel* model)
@@ -208,7 +202,9 @@ void TopLevelDataInformation::unlockPosition(const Okteta::AbstractByteArrayMode
     Q_ASSERT(mLockedPositions.contains(model) && mLockedPositions.value(model) != INVALID_OFFSET);
     qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
         << "removing lock at position" << mLockedPositions.value(model) << ", model=" << model;
-    mLockedPositions.insert(model, INVALID_OFFSET);
+    mLockedPositions.remove(model);
+    disconnect(model, &Okteta::AbstractByteArrayModel::destroyed,
+               this, &TopLevelDataInformation::removeByteArrayModelFromList);
 }
 
 void TopLevelDataInformation::removeByteArrayModelFromList(QObject* obj)
@@ -224,9 +220,9 @@ bool TopLevelDataInformation::isLockedByDefault() const
 
 void TopLevelDataInformation::setDefaultLockOffset(Okteta::Address offset)
 {
-    if (quint64(offset) == INVALID_OFFSET) {
-        // we use quint64 max to indicate not locked -> error out
-        mLogger->error() << "Attempting to lock by default at uint64_max, this is forbidden.";
+    if (offset == INVALID_OFFSET) {
+        // we use max Okteta::Address to indicate not locked -> error out
+        mLogger->error() << "Attempting to lock by default at max Okteta::Address, this is forbidden.";
         return;
     }
     mDefaultLockOffset = offset;
@@ -234,30 +230,29 @@ void TopLevelDataInformation::setDefaultLockOffset(Okteta::Address offset)
 
 void TopLevelDataInformation::newModelActivated(Okteta::AbstractByteArrayModel* model)
 {
-    // don't add null pointers to map
-    if (model && !mLockedPositions.contains(model)) {
-        // if this structure has no default lock offset, mDefaultLockOfsset will contain NOT_LOCKED
-        mLockedPositions.insert(model, mDefaultLockOffset);
-        if (mDefaultLockOffset == INVALID_OFFSET) {
-            qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
-                << "new model activated:" << model << ", not locked.";
-        } else {
-            qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
-                << "new model activated:" << model << ", locked at 0x" << QString::number(mDefaultLockOffset, 16);
-        }
+    if (!model || mLockedPositions.contains(model)) {
+        return;
+    }
+
+    if (mDefaultLockOffset != INVALID_OFFSET) {
+        qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
+            << "new model activated:" << model << ", locked at 0x" << QString::number(mDefaultLockOffset, 16);
+        lockPositionToOffset(mDefaultLockOffset, model);
+    } else {
+        qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES)
+            << "new model activated:" << model << ", not locked.";
     }
 }
 
 bool TopLevelDataInformation::isLockedFor(const Okteta::AbstractByteArrayModel* model) const
 {
-    Q_ASSERT(mLockedPositions.contains(model));
-    return mLockedPositions.value(model, 0) != INVALID_OFFSET;
+    return mLockedPositions.contains(model);
 }
 
-quint64 TopLevelDataInformation::lockPositionFor(const Okteta::AbstractByteArrayModel* model) const
+Okteta::Address TopLevelDataInformation::lockPositionFor(const Okteta::AbstractByteArrayModel* model) const
 {
     Q_ASSERT(mLockedPositions.contains(model) && mLockedPositions.value(model) != INVALID_OFFSET);
-    return mLockedPositions.value(model);
+    return mLockedPositions.value(model, INVALID_OFFSET);
 }
 
 int TopLevelDataInformation::indexOf(const DataInformation* const data) const
