@@ -21,6 +21,7 @@
 #include <KLocalizedString>
 // Qt
 #include <QModelIndex>
+#include <QByteArray>
 
 #include "script/scripthandler.hpp"
 #include "datatypes/datainformation.hpp"
@@ -33,6 +34,7 @@ StructuresTool::StructuresTool()
     , mManager(new StructuresManager(this))
     , mWritingData(false)
     , mCurrentItemDataChanged(false)
+    , mIsStructureMarked(false)
 {
     // leave mLoadedFiles empty for now, since otherwise loading slot will not work
     setObjectName(QStringLiteral("StructuresTool"));
@@ -70,6 +72,9 @@ void StructuresTool::setTargetModel(AbstractModel* model)
     // just a copy of the code in poddecodertool.h
     if (mByteArrayView) {
         mByteArrayView->disconnect(this);
+        if (mIsStructureMarked) {
+            unmark();
+        }
     }
     if (mByteArrayModel) {
         mByteArrayModel->disconnect(this);
@@ -96,7 +101,6 @@ void StructuresTool::onCursorPositionChange(Okteta::Address pos)
     if (mCursorIndex != pos) {
         mCursorIndex = pos;
         updateData(Okteta::ArrayChangeMetricsList());
-        emit cursorIndexChanged();
     }
 }
 
@@ -135,22 +139,27 @@ bool StructuresTool::setData(const QVariant& value, int role, DataInformation* i
 
     TopLevelDataInformation* topLevel = item->topLevelDataInformation();
     const Okteta::Address structureStart = startAddress(topLevel);
+    // block immediate data updating
     mWritingData = true;
+
     bool ret = false;
     BitCount64 position = item->positionInFile(structureStart);
     const quint64 remainingBits = qMax(mByteArrayModel->size() * 8 - qint64(position), qint64(0));
     quint8 bitOffs = position % 8;
     ret = item->setData(value, mByteArrayModel, Okteta::Address(position / 8), remainingBits, bitOffs);
-    mWritingData = false; // finished
-    // XXX: this is inefficient, best would be to only update the changed value
-    updateData(Okteta::ArrayChangeMetricsList()); // update once after writing
+
+    // unblock updating and catch up
+    mWritingData = false;
+    updateData(mArrayChangesWhileWriting);
+    mArrayChangesWhileWriting.clear();
+
     return ret;
 }
 
 void StructuresTool::updateData(const Okteta::ArrayChangeMetricsList& list)
 {
     if (mWritingData) {
-        qCWarning(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES) << "currently writing data, won't update";
+        mArrayChangesWhileWriting.append(list);
         return;
     }
     if (!mByteArrayModel) {
@@ -280,12 +289,38 @@ void StructuresTool::setSelectedStructuresInView()
 Okteta::Address StructuresTool::startAddress(const TopLevelDataInformation* data) const
 {
     if (data->isLockedFor(mByteArrayModel)) {
-        return Okteta::Address(data->lockPositionFor(mByteArrayModel));
+        return data->lockPositionFor(mByteArrayModel);
     }
 
     return mCursorIndex;
 }
 
+Okteta::AddressRange StructuresTool::dataRange(const DataInformation* data) const
+{
+    Q_CHECK_PTR(data->topLevelDataInformation());
+    const Okteta::Address baseAddress = startAddress(data->topLevelDataInformation());
+    // FIXME support range of partial bytes
+    int length = data->size() / 8;
+    const int maxLen = mByteArrayModel->size() - baseAddress;
+    length = qMin(length, maxLen);
+    const Okteta::Address startOffset = Okteta::Address(data->positionInFile(baseAddress) / 8);
+    return Okteta::AddressRange::fromWidth(startOffset, length);
+}
+
+void StructuresTool::selectBytesInView(const QModelIndex& idx)
+{
+    if (!mByteArrayModel || !mByteArrayView || !idx.isValid()) {
+        return;
+    }
+    const auto* data = static_cast<const DataInformation*>(idx.internalPointer());
+    if (!data) {
+        return;
+    }
+    const Okteta::AddressRange selection = dataRange(data);
+    mByteArrayView->setSelection(selection.start(), selection.end());
+    mByteArrayView->setFocus();
+}
+
 void StructuresTool::mark(const QModelIndex& idx)
 {
     if (!mByteArrayModel || !mByteArrayView || !idx.isValid()) {
@@ -295,24 +330,28 @@ void StructuresTool::mark(const QModelIndex& idx)
     if (!data) {
         return;
     }
-    Q_CHECK_PTR(data->topLevelDataInformation());
-    const Okteta::Address baseAddress = startAddress(data->topLevelDataInformation());
-    // FIXME support marking of partial bytes
-    int length = data->size() / 8;
-    const int maxLen = mByteArrayModel->size() - baseAddress;
-    length = qMin(length, maxLen);
-    const Okteta::Address startOffset = Okteta::Address(data->positionInFile(baseAddress) / 8);
-    const Okteta::AddressRange markingRange = Okteta::AddressRange::fromWidth(startOffset, length);
+    const Okteta::AddressRange markingRange = dataRange(data);
     mByteArrayView->setMarking(markingRange, true);
+    mIsStructureMarked = true;
 }
 
 void StructuresTool::unmark(/*const QModelIndex& idx*/)
 {
     if (mByteArrayView) {
         mByteArrayView->setMarking(Okteta::AddressRange());
+        mIsStructureMarked = false;
     }
 }
 
+QByteArray StructuresTool::bytes(const DataInformation* data) const
+{
+    const Okteta::AddressRange range = dataRange(data);
+    QByteArray bytes;
+    bytes.resize(range.width());
+    mByteArrayModel->copyTo(reinterpret_cast<Okteta::Byte*>(bytes.data()), range.start(), range.width());
+    return bytes;
+}
+
 void StructuresTool::validateAllStructures()
 {
     if (!mByteArrayModel) {
@@ -357,11 +396,16 @@ void StructuresTool::unlockStructure(const QModelIndex& idx)
     TopLevelDataInformation* top = data->topLevelDataInformation();
     Q_CHECK_PTR(top);
 
-    unmark();
+    const bool wasMarked = mIsStructureMarked;
+    if (wasMarked) {
+        unmark();
+    }
     top->unlockPosition(mByteArrayModel);
     // now read from the current position:
     top->read(mByteArrayModel, mCursorIndex, Okteta::ArrayChangeMetricsList(), true);
-    mark(idx); // we have to change the marked range, otherwise it stays at the previous locked offset
+    if (wasMarked) {
+        mark(idx); // we have to change the marked range, otherwise it stays at the previous locked offset
+    }
 }
 
 bool StructuresTool::isStructureLocked(const QModelIndex& idx) const
