@@ -17,6 +17,7 @@
 #include <KActionCollection>
 #include <KToolBar>
 #include <KLocalizedString>
+#include <kio_version.h>
 // Qt
 #include <QLayout>
 #include <QUrl>
@@ -61,12 +62,27 @@ void FileSystemBrowserView::init()
     layout->addWidget(mDirOperator);
 
     // fill toolbar
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    constexpr KDirOperator::Action toolbarActions[] = {
+        KDirOperator::Back,
+        KDirOperator::Forward,
+        KDirOperator::Up,
+        KDirOperator::Home,
+        KDirOperator::ShortView,
+        KDirOperator::DetailedView,
+        KDirOperator::TreeView,
+    };
+
+    for (const KDirOperator::Action toolbarAction : toolbarActions) {
+        QAction* action = mDirOperator->action(toolbarAction);
+#else
     constexpr const char* ToolbarActionNames[] =
     { "back", "forward", "up", "home", "short view", "detailed view", "tree view"  };
 
     const KActionCollection* dirOperatorActionCollection = mDirOperator->actionCollection();
     for (auto* actionName : ToolbarActionNames) {
         QAction* action = dirOperatorActionCollection->action(QLatin1String(actionName));
+#endif
         if (action) {
             mToolbar->addAction(action);
         }
